mock

package
v0.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 12, 2026 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockAsyncOperationHandler

type MockAsyncOperationHandler struct {
	mock.Mock
}

MockAsyncOperationHandler is an autogenerated mock type for the AsyncOperationHandler type

func NewMockAsyncOperationHandler

func NewMockAsyncOperationHandler(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockAsyncOperationHandler

NewMockAsyncOperationHandler creates a new instance of MockAsyncOperationHandler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockAsyncOperationHandler) EXPECT

func (*MockAsyncOperationHandler) HandleCreateErr

func (_mock *MockAsyncOperationHandler) HandleCreateErr(err error) error

HandleCreateErr provides a mock function for the type MockAsyncOperationHandler

func (*MockAsyncOperationHandler) HandleDeleteErr

func (_mock *MockAsyncOperationHandler) HandleDeleteErr(err error) error

HandleDeleteErr provides a mock function for the type MockAsyncOperationHandler

func (*MockAsyncOperationHandler) HandleOperation

func (_mock *MockAsyncOperationHandler) HandleOperation(op *operation.AsyncOperation, id string) error

HandleOperation provides a mock function for the type MockAsyncOperationHandler

func (*MockAsyncOperationHandler) HandleUpdateErr

func (_mock *MockAsyncOperationHandler) HandleUpdateErr(err error) error

HandleUpdateErr provides a mock function for the type MockAsyncOperationHandler

type MockAsyncOperationHandler_Expecter

type MockAsyncOperationHandler_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockAsyncOperationHandler_Expecter) HandleCreateErr

HandleCreateErr is a helper method to define mock.On call

  • err error

func (*MockAsyncOperationHandler_Expecter) HandleDeleteErr

HandleDeleteErr is a helper method to define mock.On call

  • err error

func (*MockAsyncOperationHandler_Expecter) HandleOperation

func (_e *MockAsyncOperationHandler_Expecter) HandleOperation(op interface{}, id interface{}) *MockAsyncOperationHandler_HandleOperation_Call

HandleOperation is a helper method to define mock.On call

  • op *operation.AsyncOperation
  • id string

func (*MockAsyncOperationHandler_Expecter) HandleUpdateErr

HandleUpdateErr is a helper method to define mock.On call

  • err error

type MockAsyncOperationHandler_HandleCreateErr_Call

type MockAsyncOperationHandler_HandleCreateErr_Call struct {
	*mock.Call
}

MockAsyncOperationHandler_HandleCreateErr_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'HandleCreateErr'

func (*MockAsyncOperationHandler_HandleCreateErr_Call) Return

func (*MockAsyncOperationHandler_HandleCreateErr_Call) Run

func (*MockAsyncOperationHandler_HandleCreateErr_Call) RunAndReturn

type MockAsyncOperationHandler_HandleDeleteErr_Call

type MockAsyncOperationHandler_HandleDeleteErr_Call struct {
	*mock.Call
}

MockAsyncOperationHandler_HandleDeleteErr_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'HandleDeleteErr'

func (*MockAsyncOperationHandler_HandleDeleteErr_Call) Return

func (*MockAsyncOperationHandler_HandleDeleteErr_Call) Run

func (*MockAsyncOperationHandler_HandleDeleteErr_Call) RunAndReturn

type MockAsyncOperationHandler_HandleOperation_Call

type MockAsyncOperationHandler_HandleOperation_Call struct {
	*mock.Call
}

MockAsyncOperationHandler_HandleOperation_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'HandleOperation'

func (*MockAsyncOperationHandler_HandleOperation_Call) Return

func (*MockAsyncOperationHandler_HandleOperation_Call) Run

func (*MockAsyncOperationHandler_HandleOperation_Call) RunAndReturn

type MockAsyncOperationHandler_HandleUpdateErr_Call

type MockAsyncOperationHandler_HandleUpdateErr_Call struct {
	*mock.Call
}

MockAsyncOperationHandler_HandleUpdateErr_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'HandleUpdateErr'

func (*MockAsyncOperationHandler_HandleUpdateErr_Call) Return

func (*MockAsyncOperationHandler_HandleUpdateErr_Call) Run

func (*MockAsyncOperationHandler_HandleUpdateErr_Call) RunAndReturn

type MockNamespaceClient

type MockNamespaceClient struct {
	mock.Mock
}

MockNamespaceClient is an autogenerated mock type for the NamespaceClient type

func NewMockNamespaceClient

func NewMockNamespaceClient(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockNamespaceClient

NewMockNamespaceClient creates a new instance of MockNamespaceClient. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockNamespaceClient) AddCACerts

func (_mock *MockNamespaceClient) AddCACerts(context1 context.Context, addCACertsParams namespace.AddCACertsParams) (*operation.AsyncOperation, error)

AddCACerts provides a mock function for the type MockNamespaceClient

func (*MockNamespaceClient) AddCertFilters

func (_mock *MockNamespaceClient) AddCertFilters(context1 context.Context, addCertFiltersParams namespace.AddCertFiltersParams) (*operation.AsyncOperation, error)

AddCertFilters provides a mock function for the type MockNamespaceClient

func (*MockNamespaceClient) CreateSearchAttribute

func (_mock *MockNamespaceClient) CreateSearchAttribute(context1 context.Context, createSearchAttributeParams namespace.CreateSearchAttributeParams) (*operation.AsyncOperation, error)

CreateSearchAttribute provides a mock function for the type MockNamespaceClient

func (*MockNamespaceClient) DeleteCACerts

func (_mock *MockNamespaceClient) DeleteCACerts(context1 context.Context, deleteCACertsParams namespace.DeleteCACertsParams) (*operation.AsyncOperation, error)

DeleteCACerts provides a mock function for the type MockNamespaceClient

func (*MockNamespaceClient) DeleteCertFilters

func (_mock *MockNamespaceClient) DeleteCertFilters(context1 context.Context, deleteCertFiltersParams namespace.DeleteCertFiltersParams) (*operation.AsyncOperation, error)

DeleteCertFilters provides a mock function for the type MockNamespaceClient

func (*MockNamespaceClient) DeleteCodec

func (_mock *MockNamespaceClient) DeleteCodec(context1 context.Context, deleteCodecParams namespace.DeleteCodecParams) (*operation.AsyncOperation, error)

DeleteCodec provides a mock function for the type MockNamespaceClient

func (*MockNamespaceClient) EXPECT

func (*MockNamespaceClient) GetCodecServer

func (_mock *MockNamespaceClient) GetCodecServer(context1 context.Context, s string) (*namespace0.CodecServerSpec, error)

GetCodecServer provides a mock function for the type MockNamespaceClient

func (*MockNamespaceClient) GetNamespace

func (_mock *MockNamespaceClient) GetNamespace(context1 context.Context, s string) (*namespace0.Namespace, error)

GetNamespace provides a mock function for the type MockNamespaceClient

func (*MockNamespaceClient) ListCACerts

func (_mock *MockNamespaceClient) ListCACerts(context1 context.Context, s string) ([]cert.CACert, error)

ListCACerts provides a mock function for the type MockNamespaceClient

func (*MockNamespaceClient) ListCertFilters

func (_mock *MockNamespaceClient) ListCertFilters(context1 context.Context, s string) ([]*namespace0.CertificateFilterSpec, error)

ListCertFilters provides a mock function for the type MockNamespaceClient

func (*MockNamespaceClient) ListSearchAttributes

func (_mock *MockNamespaceClient) ListSearchAttributes(context1 context.Context, s string) ([]namespace.SearchAttribute, error)

ListSearchAttributes provides a mock function for the type MockNamespaceClient

func (*MockNamespaceClient) RenameSearchAttribute

func (_mock *MockNamespaceClient) RenameSearchAttribute(context1 context.Context, renameSearchAttributeParams namespace.RenameSearchAttributeParams) (*operation.AsyncOperation, error)

RenameSearchAttribute provides a mock function for the type MockNamespaceClient

func (*MockNamespaceClient) SetCodec

func (_mock *MockNamespaceClient) SetCodec(context1 context.Context, setCodecParams namespace.SetCodecParams) (*operation.AsyncOperation, error)

SetCodec provides a mock function for the type MockNamespaceClient

func (*MockNamespaceClient) UpdateNamespace

func (_mock *MockNamespaceClient) UpdateNamespace(context1 context.Context, updateNamespaceParams namespace.UpdateNamespaceParams) (*operation.AsyncOperation, error)

UpdateNamespace provides a mock function for the type MockNamespaceClient

type MockNamespaceClient_AddCACerts_Call

type MockNamespaceClient_AddCACerts_Call struct {
	*mock.Call
}

MockNamespaceClient_AddCACerts_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'AddCACerts'

func (*MockNamespaceClient_AddCACerts_Call) Return

func (*MockNamespaceClient_AddCACerts_Call) Run

func (*MockNamespaceClient_AddCACerts_Call) RunAndReturn

type MockNamespaceClient_AddCertFilters_Call

type MockNamespaceClient_AddCertFilters_Call struct {
	*mock.Call
}

MockNamespaceClient_AddCertFilters_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'AddCertFilters'

func (*MockNamespaceClient_AddCertFilters_Call) Return

func (*MockNamespaceClient_AddCertFilters_Call) Run

func (*MockNamespaceClient_AddCertFilters_Call) RunAndReturn

type MockNamespaceClient_CreateSearchAttribute_Call

type MockNamespaceClient_CreateSearchAttribute_Call struct {
	*mock.Call
}

MockNamespaceClient_CreateSearchAttribute_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'CreateSearchAttribute'

func (*MockNamespaceClient_CreateSearchAttribute_Call) Return

func (*MockNamespaceClient_CreateSearchAttribute_Call) Run

func (*MockNamespaceClient_CreateSearchAttribute_Call) RunAndReturn

type MockNamespaceClient_DeleteCACerts_Call

type MockNamespaceClient_DeleteCACerts_Call struct {
	*mock.Call
}

MockNamespaceClient_DeleteCACerts_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'DeleteCACerts'

func (*MockNamespaceClient_DeleteCACerts_Call) Return

func (*MockNamespaceClient_DeleteCACerts_Call) Run

func (*MockNamespaceClient_DeleteCACerts_Call) RunAndReturn

type MockNamespaceClient_DeleteCertFilters_Call

type MockNamespaceClient_DeleteCertFilters_Call struct {
	*mock.Call
}

MockNamespaceClient_DeleteCertFilters_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'DeleteCertFilters'

func (*MockNamespaceClient_DeleteCertFilters_Call) Return

func (*MockNamespaceClient_DeleteCertFilters_Call) Run

func (*MockNamespaceClient_DeleteCertFilters_Call) RunAndReturn

type MockNamespaceClient_DeleteCodec_Call

type MockNamespaceClient_DeleteCodec_Call struct {
	*mock.Call
}

MockNamespaceClient_DeleteCodec_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'DeleteCodec'

func (*MockNamespaceClient_DeleteCodec_Call) Return

func (*MockNamespaceClient_DeleteCodec_Call) Run

func (*MockNamespaceClient_DeleteCodec_Call) RunAndReturn

type MockNamespaceClient_Expecter

type MockNamespaceClient_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockNamespaceClient_Expecter) AddCACerts

func (_e *MockNamespaceClient_Expecter) AddCACerts(context1 interface{}, addCACertsParams interface{}) *MockNamespaceClient_AddCACerts_Call

AddCACerts is a helper method to define mock.On call

  • context1 context.Context
  • addCACertsParams namespace.AddCACertsParams

func (*MockNamespaceClient_Expecter) AddCertFilters

func (_e *MockNamespaceClient_Expecter) AddCertFilters(context1 interface{}, addCertFiltersParams interface{}) *MockNamespaceClient_AddCertFilters_Call

AddCertFilters is a helper method to define mock.On call

  • context1 context.Context
  • addCertFiltersParams namespace.AddCertFiltersParams

func (*MockNamespaceClient_Expecter) CreateSearchAttribute

func (_e *MockNamespaceClient_Expecter) CreateSearchAttribute(context1 interface{}, createSearchAttributeParams interface{}) *MockNamespaceClient_CreateSearchAttribute_Call

CreateSearchAttribute is a helper method to define mock.On call

  • context1 context.Context
  • createSearchAttributeParams namespace.CreateSearchAttributeParams

func (*MockNamespaceClient_Expecter) DeleteCACerts

func (_e *MockNamespaceClient_Expecter) DeleteCACerts(context1 interface{}, deleteCACertsParams interface{}) *MockNamespaceClient_DeleteCACerts_Call

DeleteCACerts is a helper method to define mock.On call

  • context1 context.Context
  • deleteCACertsParams namespace.DeleteCACertsParams

func (*MockNamespaceClient_Expecter) DeleteCertFilters

func (_e *MockNamespaceClient_Expecter) DeleteCertFilters(context1 interface{}, deleteCertFiltersParams interface{}) *MockNamespaceClient_DeleteCertFilters_Call

DeleteCertFilters is a helper method to define mock.On call

  • context1 context.Context
  • deleteCertFiltersParams namespace.DeleteCertFiltersParams

func (*MockNamespaceClient_Expecter) DeleteCodec

func (_e *MockNamespaceClient_Expecter) DeleteCodec(context1 interface{}, deleteCodecParams interface{}) *MockNamespaceClient_DeleteCodec_Call

DeleteCodec is a helper method to define mock.On call

  • context1 context.Context
  • deleteCodecParams namespace.DeleteCodecParams

func (*MockNamespaceClient_Expecter) GetCodecServer

func (_e *MockNamespaceClient_Expecter) GetCodecServer(context1 interface{}, s interface{}) *MockNamespaceClient_GetCodecServer_Call

GetCodecServer is a helper method to define mock.On call

  • context1 context.Context
  • s string

func (*MockNamespaceClient_Expecter) GetNamespace

func (_e *MockNamespaceClient_Expecter) GetNamespace(context1 interface{}, s interface{}) *MockNamespaceClient_GetNamespace_Call

GetNamespace is a helper method to define mock.On call

  • context1 context.Context
  • s string

func (*MockNamespaceClient_Expecter) ListCACerts

func (_e *MockNamespaceClient_Expecter) ListCACerts(context1 interface{}, s interface{}) *MockNamespaceClient_ListCACerts_Call

ListCACerts is a helper method to define mock.On call

  • context1 context.Context
  • s string

func (*MockNamespaceClient_Expecter) ListCertFilters

func (_e *MockNamespaceClient_Expecter) ListCertFilters(context1 interface{}, s interface{}) *MockNamespaceClient_ListCertFilters_Call

ListCertFilters is a helper method to define mock.On call

  • context1 context.Context
  • s string

func (*MockNamespaceClient_Expecter) ListSearchAttributes

func (_e *MockNamespaceClient_Expecter) ListSearchAttributes(context1 interface{}, s interface{}) *MockNamespaceClient_ListSearchAttributes_Call

ListSearchAttributes is a helper method to define mock.On call

  • context1 context.Context
  • s string

func (*MockNamespaceClient_Expecter) RenameSearchAttribute

func (_e *MockNamespaceClient_Expecter) RenameSearchAttribute(context1 interface{}, renameSearchAttributeParams interface{}) *MockNamespaceClient_RenameSearchAttribute_Call

RenameSearchAttribute is a helper method to define mock.On call

  • context1 context.Context
  • renameSearchAttributeParams namespace.RenameSearchAttributeParams

func (*MockNamespaceClient_Expecter) SetCodec

func (_e *MockNamespaceClient_Expecter) SetCodec(context1 interface{}, setCodecParams interface{}) *MockNamespaceClient_SetCodec_Call

SetCodec is a helper method to define mock.On call

  • context1 context.Context
  • setCodecParams namespace.SetCodecParams

func (*MockNamespaceClient_Expecter) UpdateNamespace

func (_e *MockNamespaceClient_Expecter) UpdateNamespace(context1 interface{}, updateNamespaceParams interface{}) *MockNamespaceClient_UpdateNamespace_Call

UpdateNamespace is a helper method to define mock.On call

  • context1 context.Context
  • updateNamespaceParams namespace.UpdateNamespaceParams

type MockNamespaceClient_GetCodecServer_Call

type MockNamespaceClient_GetCodecServer_Call struct {
	*mock.Call
}

MockNamespaceClient_GetCodecServer_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetCodecServer'

func (*MockNamespaceClient_GetCodecServer_Call) Return

func (*MockNamespaceClient_GetCodecServer_Call) Run

func (*MockNamespaceClient_GetCodecServer_Call) RunAndReturn

type MockNamespaceClient_GetNamespace_Call

type MockNamespaceClient_GetNamespace_Call struct {
	*mock.Call
}

MockNamespaceClient_GetNamespace_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetNamespace'

func (*MockNamespaceClient_GetNamespace_Call) Return

func (*MockNamespaceClient_GetNamespace_Call) Run

func (*MockNamespaceClient_GetNamespace_Call) RunAndReturn

type MockNamespaceClient_ListCACerts_Call

type MockNamespaceClient_ListCACerts_Call struct {
	*mock.Call
}

MockNamespaceClient_ListCACerts_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'ListCACerts'

func (*MockNamespaceClient_ListCACerts_Call) Return

func (*MockNamespaceClient_ListCACerts_Call) Run

func (*MockNamespaceClient_ListCACerts_Call) RunAndReturn

type MockNamespaceClient_ListCertFilters_Call

type MockNamespaceClient_ListCertFilters_Call struct {
	*mock.Call
}

MockNamespaceClient_ListCertFilters_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'ListCertFilters'

func (*MockNamespaceClient_ListCertFilters_Call) Return

func (*MockNamespaceClient_ListCertFilters_Call) Run

func (*MockNamespaceClient_ListCertFilters_Call) RunAndReturn

type MockNamespaceClient_ListSearchAttributes_Call

type MockNamespaceClient_ListSearchAttributes_Call struct {
	*mock.Call
}

MockNamespaceClient_ListSearchAttributes_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'ListSearchAttributes'

func (*MockNamespaceClient_ListSearchAttributes_Call) Return

func (*MockNamespaceClient_ListSearchAttributes_Call) Run

func (*MockNamespaceClient_ListSearchAttributes_Call) RunAndReturn

type MockNamespaceClient_RenameSearchAttribute_Call

type MockNamespaceClient_RenameSearchAttribute_Call struct {
	*mock.Call
}

MockNamespaceClient_RenameSearchAttribute_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'RenameSearchAttribute'

func (*MockNamespaceClient_RenameSearchAttribute_Call) Return

func (*MockNamespaceClient_RenameSearchAttribute_Call) Run

func (*MockNamespaceClient_RenameSearchAttribute_Call) RunAndReturn

type MockNamespaceClient_SetCodec_Call

type MockNamespaceClient_SetCodec_Call struct {
	*mock.Call
}

MockNamespaceClient_SetCodec_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'SetCodec'

func (*MockNamespaceClient_SetCodec_Call) Return

func (*MockNamespaceClient_SetCodec_Call) Run

func (*MockNamespaceClient_SetCodec_Call) RunAndReturn

type MockNamespaceClient_UpdateNamespace_Call

type MockNamespaceClient_UpdateNamespace_Call struct {
	*mock.Call
}

MockNamespaceClient_UpdateNamespace_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'UpdateNamespace'

func (*MockNamespaceClient_UpdateNamespace_Call) Return

func (*MockNamespaceClient_UpdateNamespace_Call) Run

func (*MockNamespaceClient_UpdateNamespace_Call) RunAndReturn

type MockPoller

type MockPoller struct {
	mock.Mock
}

MockPoller is an autogenerated mock type for the Poller type

func NewMockPoller

func NewMockPoller(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockPoller

NewMockPoller creates a new instance of MockPoller. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockPoller) EXPECT

func (_m *MockPoller) EXPECT() *MockPoller_Expecter

func (*MockPoller) PollAsyncOperation

func (_mock *MockPoller) PollAsyncOperation(commandContext *temporalcloudcli.CommandContext, s string, s1 string) error

PollAsyncOperation provides a mock function for the type MockPoller

type MockPoller_Expecter

type MockPoller_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockPoller_Expecter) PollAsyncOperation

func (_e *MockPoller_Expecter) PollAsyncOperation(commandContext interface{}, s interface{}, s1 interface{}) *MockPoller_PollAsyncOperation_Call

PollAsyncOperation is a helper method to define mock.On call

  • commandContext *temporalcloudcli.CommandContext
  • s string
  • s1 string

type MockPoller_PollAsyncOperation_Call

type MockPoller_PollAsyncOperation_Call struct {
	*mock.Call
}

MockPoller_PollAsyncOperation_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'PollAsyncOperation'

func (*MockPoller_PollAsyncOperation_Call) Return

func (*MockPoller_PollAsyncOperation_Call) Run

func (*MockPoller_PollAsyncOperation_Call) RunAndReturn

type MockPrompter

type MockPrompter struct {
	mock.Mock
}

MockPrompter is an autogenerated mock type for the Prompter type

func NewMockPrompter

func NewMockPrompter(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockPrompter

NewMockPrompter creates a new instance of MockPrompter. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockPrompter) EXPECT

func (_m *MockPrompter) EXPECT() *MockPrompter_Expecter

func (*MockPrompter) PromptApply

func (_mock *MockPrompter) PromptApply(old proto.Message, new proto.Message, verbose bool) error

PromptApply provides a mock function for the type MockPrompter

type MockPrompter_Expecter

type MockPrompter_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockPrompter_Expecter) PromptApply

func (_e *MockPrompter_Expecter) PromptApply(old interface{}, new interface{}, verbose interface{}) *MockPrompter_PromptApply_Call

PromptApply is a helper method to define mock.On call

  • old proto.Message
  • new proto.Message
  • verbose bool

type MockPrompter_PromptApply_Call

type MockPrompter_PromptApply_Call struct {
	*mock.Call
}

MockPrompter_PromptApply_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'PromptApply'

func (*MockPrompter_PromptApply_Call) Return

func (*MockPrompter_PromptApply_Call) Run

func (*MockPrompter_PromptApply_Call) RunAndReturn

func (_c *MockPrompter_PromptApply_Call) RunAndReturn(run func(old proto.Message, new proto.Message, verbose bool) error) *MockPrompter_PromptApply_Call

Jump to